@@ -1,22 +1,21 @@
-import redis
+import connection
 
 from scrapy.utils.misc import load_object
 from scrapy_redis.dupefilter import RFPDupeFilter
 
 
 # default values
-REDIS_HOST = 'localhost'
-REDIS_PORT = 6379
 SCHEDULER_PERSIST = False
 QUEUE_KEY = '%(spider)s:requests'
 QUEUE_CLASS = 'scrapy_redis.queue.SpiderPriorityQueue'
 DUPEFILTER_KEY = '%(spider)s:dupefilter'
+IDLE_BEFORE_CLOSE = 0
 
 
 class Scheduler(object):
     """Redis-based scheduler"""
 
-    def __init__(self, server, persist, queue_key, queue_cls, dupefilter_key):
+    def __init__(self, server, persist, queue_key, queue_cls, dupefilter_key, idle_before_close):
         """Initialize scheduler.
 
         Parameters
@@ -26,12 +25,14 @@ class Scheduler(object):
         queue_key : str
         queue_cls : queue class
         dupefilter_key : str
+        idle_before_close : int
         """
         self.server = server
         self.persist = persist
         self.queue_key = queue_key
         self.queue_cls = queue_cls
         self.dupefilter_key = dupefilter_key
+        self.idle_before_close = idle_before_close
         self.stats = None
 
     def __len__(self):
@@ -39,14 +40,13 @@ class Scheduler(object):
 
     @classmethod
     def from_settings(cls, settings):
-        host = settings.get('REDIS_HOST', REDIS_HOST)
-        port = settings.get('REDIS_PORT', REDIS_PORT)
         persist = settings.get('SCHEDULER_PERSIST', SCHEDULER_PERSIST)
         queue_key = settings.get('SCHEDULER_QUEUE_KEY', QUEUE_KEY)
         queue_cls = load_object(settings.get('SCHEDULER_QUEUE_CLASS', QUEUE_CLASS))
         dupefilter_key = settings.get('DUPEFILTER_KEY', DUPEFILTER_KEY)
-        server = redis.Redis(host, port)
-        return cls(server, persist, queue_key, queue_cls, dupefilter_key)
+        idle_before_close = settings.get('SCHEDULER_IDLE_BEFORE_CLOSE', IDLE_BEFORE_CLOSE)
+        server = connection.from_settings(settings)
+        return cls(server, persist, queue_key, queue_cls, dupefilter_key, idle_before_close)
 
     @classmethod
     def from_crawler(cls, crawler):
@@ -59,6 +59,8 @@ class Scheduler(object):
         self.spider = spider
         self.queue = self.queue_cls(self.server, spider, self.queue_key)
         self.df = RFPDupeFilter(self.server, self.dupefilter_key % {'spider': spider.name})
+        if self.idle_before_close < 0:
+            self.idle_before_close = 0
         # notice if there are requests already in the queue to resume the crawl
         if len(self.queue):
             spider.log("Resuming crawl (%d requests scheduled)" % len(self.queue))
@@ -76,7 +78,8 @@ class Scheduler(object):
         self.queue.push(request)
 
     def next_request(self):
-        request = self.queue.pop()
+        block_pop_timeout = self.idle_before_close
+        request = self.queue.pop(block_pop_timeout)
         if request and self.stats:
             self.stats.inc_value('scheduler/dequeued/redis', spider=self.spider)
         return request
