@@ -21,7 +21,7 @@ class RedisMixin(object):
         # idle signal is called when the spider has no requests left,
         # that's when we will schedule new requests from redis queue
         self.crawler.signals.connect(self.spider_idle, signal=signals.spider_idle)
-        self.log("Reading URLs from redis list '%s' at %s:%s." % (self.redis_key, host, port))
+        self.log("Reading URLs from redis list '%s'" % self.redis_key)
 
     def next_request(self):
         """Returns a request to be scheduled or none."""
